<?php
print (basename(__FILE__).": Init...\n");

// Change directory
@chdir("..");

// Load config file
require(dirname(dirname(__FILE__)) . '/inc/config.php');

// Load all include files
require($cfg->readConfig('base_path') . 'inc/includes.php');

// Load all game classes
require($cfg->readConfig('base_path') . 'inc/classes.php');

// Set default application
FrameworkConfiguration::getInstance()->setConfigEntry('default_application', 'ship-simu');

// Set testing mode (no starter.php will be loaded!)
define('TEST_MODE', true);

// Load the PHPUnit framework
require_once('PHPUnit/Framework.php');

print (basename(__FILE__).": Init completed.\n\n");

/**
 * A test case for faked HTTP requests. This is faked because we *set*
 * $_REQUEST here. This should be made better in PHP6... :(
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007 - 2009 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 * @see			http://www.phpunit.de
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class RequestTest extends PHPUnit_Framework_TestCase {
	/**
	 * A non-exist request element is being asked for. null is the expected
	 * result from the class
	 *
	 * @return	void
	 */
	public function testMissingRequestElement () {
		// Get a request instance
		$requestInstance = HttpRequest::createHttpRequest();

		// Get the element
		$nonExist = $requestInstance->getRequestElement('never_there');

		// Is this null?
		if (!is_null($nonExist)) {
			// Is not null!
			$this->fail(sprintf("[%s:] Unexpected type %s received from request handler.",
				$requestInstance->__toString(),
				gettype($nonExists)
			));
		}
	}

	/**
	 * Now fake a request array and try the test on it again
	 *
	 * @return	void
	 */
	public function testFakeRequestElement () {
		// Fake the request here
		$_REQUEST = array('test_key' => "test_value");

		// Again get an instance
		$requestInstance = HttpRequest::createHttpRequest();

		// Get the element
		$testValue = $requestInstance->getRequestElement('test_key');

		// Is it the same?
		if ($testValue !== "test_value") {
			// Something went wrong
			$this->fail(sprintf("[%s] Unexpected value %s (%s) from test key received.",
				$requestInstance->__toString(),
				$testValue,
				gettype($testValue)
			));
		}
	}
}

?>
